module.exports = defineTest({
	description: 'supports the new.target meta property'
});
